@@ -36,8 +36,55 @@
 #include FT_INTERNAL_OBJECTS_H
 #include FT_INTERNAL_DRIVER_H
 
+  /* FSSpec functions are deprecated since Mac OS X 10.4 */
+#ifndef HAVE_FSSPEC
+#if defined( __LP64__ ) && !TARGET_CPU_68K && !TARGET_CPU_PPC && !TARGET_CPU_PPC64
+#define HAVE_FSSPEC  0
+typedef void FSSpec;
+#else
+#define HAVE_FSSPEC  1
+#endif
+#endif
+
+  /* most FSRef functions were introduced since Mac OS 9 */
+#ifndef HAVE_FSREF
+#if TARGET_API_MAC_OSX
+#define HAVE_FSREF  1
+#else
+#define HAVE_FSREF  0
+typedef void FSRef;
+#endif
+#endif
+
+  /* QuickDraw is deprecated since Mac OS X 10.4 */
+#ifndef HAVE_QUICKDRAW_CARBON
+#if defined( __LP64__ ) && !TARGET_CPU_68K && !TARGET_CPU_PPC && !TARGET_CPU_PPC64
+#define HAVE_QUICKDRAW_CARBON  0
+#define HAVE_QUICKDRAW_TOOLBOX 0
+#elif TARGET_API_MAC_CARBON || TARGET_API_MAC_OSX
+#define HAVE_QUICKDRAW_CARBON  1
+#define HAVE_QUICKDRAW_TOOLBOX 1
+#elif TARGET_API_MAC_OS8
+#define HAVE_QUICKDRAW_CARBON  0
+#define HAVE_QUICKDRAW_TOOLBOX 1
+#endif
+#endif
+
+  /* AppleTypeService is available since Mac OS X */
+#ifndef HAVE_ATS
+#if TARGET_API_MAC_OSX
+#define HAVE_ATS  1
+#else
+#define HAVE_ATS  0
+#endif
+#endif
+
 #include FT_MAC_H
 
+#undef FT_GetFile_From_Mac_Name
+#undef FT_GetFile_From_Mac_ATS_Name
+#undef FT_New_Face_From_FSSpec
+
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
@@ -120,7 +167,7 @@ void
 dump_face_info( FT_Face  face )
 {
   printf( "\t\tface_index=%d, face_flags=0x%08x, num_glyphs=%d\n",
-              (int)face->face_index, 
+              (int)face->face_index,
               (unsigned int)(face->face_flags),
               (int)face->num_glyphs );
   printf( "\t\tnum_fixed_sizes=%d, style_flags=%d%d%d%d%d%d\n",
@@ -136,7 +183,7 @@ dump_face_info( FT_Face  face )
           face->family_name, face->style_name );
 }
 
- 
+
 void
 crawlFontFile( char*  font_file_path )
 {
@@ -171,7 +218,7 @@ crawlFontFile( char*  font_file_path )
   num_opened_fonts ++;
   printf( "\tFont file has %d face\n", (int)face->num_faces );
 
-  
+
   j = face->num_faces + max_face_number;
   for ( i = 0; i < j; i++ )
   {
@@ -413,7 +460,7 @@ test_font_files( int     argc,
 
 
 void
-print_help()
+print_help_and_exit()
 {
   printf("\n" );
   printf(" ftoldmac  [pathname in HFS syntax]\n" );
@@ -440,6 +487,19 @@ print_help()
   printf("           old QuickDraw API cannot list available style suffixes,\n" );
   printf("           this option adds Bold and Italic suffixes automatically.\n" );
   printf("\n" );
+  printf("           available API:" );
+#if HAVE_QUICKDRAW_TOOLBOX
+  printf(" quickdraw_old" );
+#endif
+#if HAVE_QUICKDRAW_CARBON
+  printf(" quickdraw" );
+#endif
+#if HAVE_ATS
+  printf(" ats" );
+#endif
+  printf("\n" );
+  printf("\n" );
+  exit( 0 );
 }
 
 
@@ -487,8 +547,8 @@ verifyFMOutput( FMOutput*  fmout )
 FT_OldMac_Err
 resolveToolBoxQuickDrawFontName( const char*  font_name )
 {
-#if !defined( HAVE_QUICKDRAW_CARBON ) || ( QUICKDRAW_CARBON == 0 )
-  printf( "cannot check [%s] by Carbon QuickDraw\n", font_name );
+#if !HAVE_QUICKDRAW_TOOLBOX
+  printf( "cannot check [%s] by Toolbox QuickDraw\n", font_name );
   return FT_OldMac_Err_Unimplemented;
 #else
   Str255     familyName;
@@ -503,7 +563,7 @@ resolveToolBoxQuickDrawFontName( const char*  font_name )
   if ( 0 > familyID )
   {
     printf( "familyName %s is unresolvable\n", familyName + 1 );
-    return FT_OldMac_Err_Unresolvable;
+    return FT_OldMac_Err_UnresolvableFontName;
   }
   else if ( 0 == familyID )
     return FT_OldMac_Err_PseudoFontName;
@@ -540,9 +600,12 @@ void
 test_face_quickdraw( char*       face_name,
                      FT_Library  library    )
 {
+#if !HAVE_QUICKDRAW_CARBON
+  printf( "cannot check [%s] by Carbon QuickDraw\n", face_name );
+#else
   FSSpec   spec;
   UInt8    font_file_path[1024];
-  FT_Long  face_index; 
+  FT_Long  face_index;
   FT_Face  face;
 
 
@@ -565,6 +628,7 @@ test_face_quickdraw( char*       face_name,
   num_opened_faces ++;
   dump_face_info( face );
   FT_Done_Face( face );
+#endif
 }
 
 
@@ -572,14 +636,14 @@ void
 test_face_ats( char*       face_name,
                FT_Library  library    )
 {
-#if !defined( HAVE_ATS ) || ( HAVE_ATS == 0 )
+#if !HAVE_ATS
   FT_UNUSED( library );
   printf( "cannot check [%s] by ATS\n", face_name );
 #else
-  FSSpec   spec;
   UInt8    font_file_path[1024];
-  FT_Long  face_index; 
+  FT_Long  face_index;
   FT_Face  face;
+  FSSpec   spec;
 
 
   printf( "Lookup [%s]...", face_name );
@@ -590,7 +654,9 @@ test_face_ats( char*       face_name,
   }
 
   ftmac_FSpMakePath( &spec, font_file_path, 1024 );
+
   printf( "Font file found [%s], face #%d...", font_file_path, (int)face_index );
+
   if ( 0 != FT_New_Face_From_FSSpec( library, &spec, face_index, &face ) )
   {
     printf( "FreeType could not load font file\n" );
@@ -615,7 +681,7 @@ test_face( char*       face_name,
   else if ( 0 == ft_strcmp( font_resolve_api, "ats" ) )
     test_face_ats( face_name, library );
   else
-  { 
+  {
     printf( "invalid api name to resolve [%s]\n", font_resolve_api );
     exit( -1 );
   }
@@ -625,6 +691,10 @@ test_face( char*       face_name,
 void
 test_font_list_quickdraw_old( FT_Library  library )
 {
+#if !HAVE_QUICKDRAW_TOOLBOX
+  FT_UNUSED( library );
+  printf( "FreeType2 is configured without quickdraw_old (Toolbox QuickDraw)\n" );
+#else
   Str255  fmo_family_name;
   char    fmo_face_name[1024];
   int     i;
@@ -659,6 +729,7 @@ test_font_list_quickdraw_old( FT_Library  library )
       test_face( fmo_face_name, library );
     }
   }
+#endif
 }
 
 
@@ -685,9 +756,9 @@ make_style_suffix( char*        fm_style_name,
 void
 test_font_list_quickdraw( FT_Library  library )
 {
-#if !defined( HAVE_QUICKDRAW_CARBON ) || ( QUICKDRAW_CARBON == 0 )
+#if !HAVE_QUICKDRAW_CARBON
   FT_UNUSED( library );
-  printf( "cannot get font list by Carbon QuickDraw\n" );
+  printf( "FreeType2 is configured without quickdraw (Carbon QuickDraw)\n" );
 #else
   FMFontFamilyIterator          fm_family_iter;
   FMFontFamily                  fm_family;
@@ -706,7 +777,7 @@ test_font_list_quickdraw( FT_Library  library )
                                         kFMUseGlobalScopeOption,
                                         &fm_family_iter ) )
     return;
-  
+
 get_quickdraw_font_family:
   if ( 0 == FMGetNextFontFamily( &fm_family_iter, &fm_family ) )
   {
@@ -743,14 +814,17 @@ get_quickdraw_font_instance:
 void
 test_font_list_ats( FT_Library  library )
 {
-#if !defined( HAVE_ATS ) || ( HAVE_ATS == 0 )
+#if !HAVE_ATS
   FT_UNUSED( library );
-  printf( "cannot get font list by ATS\n" );
+  printf( "FreeType2 is configured without ats (AppleTypeService)\n" );
 #else
   ATSFontIterator  ats_font_iter;
   ATSFontRef       ats_font_ref;
   CFStringRef      ats_font_name;
   char             face_name[1024];
+#ifndef kATSOptionFlagsUnRestrictedScope
+#define kATSOptionFlagsUnRestrictedScope kATSOptionFlagsDefault
+#endif
 
 
   if ( noErr != ATSFontIteratorCreate( kATSFontContextGlobal,
@@ -794,7 +868,7 @@ test_system_font_list()
   else if ( 0 == ft_strcmp( font_listing_api, "ats" ) )
     test_font_list_ats( library );
   else
-  { 
+  {
     printf( "invalid api name to list [%s]\n", font_listing_api );
     exit( -1 );
   }
@@ -822,16 +896,13 @@ main( int     argc,
   force_scan_face  = FALSE;
 
   if ( 1 == argc )
-    print_help();
+    print_help_and_exit();
   else
   {
-    for ( i = 1; i < argc; i++ ) 
+    for ( i = 1; i < argc; i++ )
     {
       if ( 0 == ft_strcmp( "--help", argv[i] ) )
-      {
-        print_help();
-        exit( 0 );
-      }
+        print_help_and_exit();
       else if ( 0 == ft_strncmp( "--font-listing-api=", argv[i], 19 ) )
         font_listing_api = argv[i] + 19;
       else if ( 0 == ft_strncmp( "--font-resolve-api=", argv[i], 19 ) )
